OC.L10N.register(
    "settings",
    {
    "Authentication error" : "ခွင့်ပြုချက်မအောင်မြင်",
    "Invalid request" : "တောင်းဆိုချက်မမှန်ကန်ပါ",
    "Cancel" : "ပယ်ဖျက်မည်",
    "Password" : "စကားဝှက်",
    "New password" : "စကားဝှက်အသစ်",
    "Username" : "သုံးစွဲသူအမည်",
    "Admin" : "အက်ဒမင်"
},
"nplurals=1; plural=0;");
